==> haskell-fingertree-0.1.4.2-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fingertree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fingertree
version: 0.1.4.2
id: fingertree-0.1.4.2-LeCTjI4pbvPGZmWHDe4eRB
key: fingertree-0.1.4.2-LeCTjI4pbvPGZmWHDe4eRB
license: BSD-3-Clause
copyright: (c) 2006 Ross Paterson, Ralf Hinze
maintainer: Ross Paterson <R.Paterson@city.ac.uk>
synopsis: Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of
    .
    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>
    .
    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.
category: Data Structures
abi: 164e297d5f6b3c8ae8f5fa01e26e0ef3
exposed: True
exposed-modules:
    Data.FingerTree Data.IntervalMap.FingerTree
    Data.PriorityQueue.FingerTree
import-dirs: /usr/lib/ghc-8.6.5/site-local/fingertree-0.1.4.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/fingertree-0.1.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/fingertree-0.1.4.2
hs-libraries: HSfingertree-0.1.4.2-LeCTjI4pbvPGZmWHDe4eRB
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-fingertree/html/fingertree.haddock
haddock-html: /usr/share/doc/haskell-fingertree/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fingertree-0.1.4.2-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fingertree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fingertree
version: 0.1.4.2
id: fingertree-0.1.4.2-67r0jo5EVKpAdNcjLxEnyG
key: fingertree-0.1.4.2-67r0jo5EVKpAdNcjLxEnyG
license: BSD-3-Clause
copyright: (c) 2006 Ross Paterson, Ralf Hinze
maintainer: Ross Paterson <R.Paterson@city.ac.uk>
synopsis: Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of
    .
    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>
    .
    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.
category: Data Structures
abi: 3db11f8f03503e299bb4dd6efc3ab155
exposed: True
exposed-modules:
    Data.FingerTree Data.IntervalMap.FingerTree
    Data.PriorityQueue.FingerTree
import-dirs: /usr/lib/ghc-8.6.5/site-local/fingertree-0.1.4.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/fingertree-0.1.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/fingertree-0.1.4.2
hs-libraries: HSfingertree-0.1.4.2-67r0jo5EVKpAdNcjLxEnyG
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-fingertree/html/fingertree.haddock
haddock-html: /usr/share/doc/haskell-fingertree/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
